## [1.3.3] - Inquisitive Imps
* Drivers and Tilt Five Software Install
  * Cancel pending data sends over USB to avoid blocking potentially forever in certain conditions
  * Fix issue where the list of active Glasses could be accessed without synchronization

* Client Libraries (Developer SDK)
  * Fix issue with some AMD graphics drivers that could cause frame glitches
  * Added timeouts and additional synchronization to avoid blocking clients indefinitely when Glasses are removed and re-attached quickly

* Unity Plug-in (Developer SDK)
  * Maintain a Tilt Five Player index to Unity Input System player number mapping to track Glasses player indexes over time
  * Create a playerTemplate on GlassesSettings that developers can use to spawn an object independent of the Glasses Object for things like player input processing (#887)
    * Use of InputUser objects in the Glasses Object Prefab is deprecated and will generate warning debugging output
    * For compatibility with earlier SDK versions, such objects in the Glasses Object Prefab will continue to function as before unless a GlassesSettings.playerTemplate is specified
  * Fix left-/right-hand Wand Input System Action Maps, where specific hand Wand control mappings were not working (#1008)
  * Use new client implementation to avoid causing Unity projects to freeze and/or crash when Glasses are removed and re-attached quickly

## [1.3.2] - Inquisitive Imps
* Control Panel
  * Glasses are now sorted by any "friendly name" assigned to them or their serial number

* Glasses
  * Platform stability fixes

* Unity Plug-in (Developer SDK)
  * *This is a recommended upgrade for projects currently using 1.3.0 or 1.3.1 SDKs*
  * Fix a compile-time error when Input System is used in a project  (regression in 1.3.1 #922)
  * Retrieve and assign Glasses for Player 1 and up based on the order defined by the Service and as seen in Control Panel instead of by Glasses serial number

* Known Issues
  * [Windows] Control Panel: Window position is not remembered between runs as expected #934
  * Service: Glasses' Friendly name sorting is a strictly lexicographical ordering by UTF-8 code points #941
  * [Android] Unity Plug-in: Some of the SDK examples have issues when built for Android #940

## [1.3.1] - Inquisitive Imps
* Control Panel
  * (Windows/Linux) The Control Panel now remembers where it is located on your screen between runs

* Glasses
  * Fix for occasional rejected IMU samples due to a timestamp firmware bug on the IMU
  * Fix some startup failures due to a timeout waiting for all modules to start
  * Fix headset tracking loss when viewing content from angles near the corners of the GameBoard

* Drivers and Tilt Five Software Install
  * Fix stalls sending frames over USB where the completion of send could be delayed an extra frame
  * Bugfixes around communication with the service including prevention of some data races
  * Fix crash in Camera Viewer tool that could happen when unplugging Glasses
  * (Windows) The system notification icon when no glasses are attached is now the Tilt Five logo
  * Logging improvements

* Android Platform (Beta)
  * Add Android 10 or later as a supported platform for developers
  * Add Tilt Five (Control Panel and Service) APK in the Developer SDK for loading on devices

* Linux Platform (Experimental)
  * Add Linux x86-64 binary Driver and Tilt Five Software tarball
  * Add Linux Developer SDK tarball which includes the same content as the Windows SDK Installer

* Developer Tools (Developer SDK)
  * Remove the Wand Reflection executable demo
  * Update tooling for Android builds of the SDK to make one APK for both Control Panel and Service

* NDK Beta (Developer SDK)
  * Update release notes in NDK documentation
  * Add Android version of the NDK library
  * Add Linux x86-64 version of the NDK library

* Unity Plug-in (Developer SDK)
  * Add an option to toggle inversion of the Gameboard `GameObject` transform scale, which was incorrectly inverted in all previous SDK versions, making it difficult to reason about how other Gameboard-relative objects would transform when scaling the Gameboard; to ease the transition for existing projects, the inverted behavior is being kept the default until at least version 1.4.0, but turning it off is strongly
  advised for new projects
  * Assign a parent transform for the player's head pose in the per-player prefab during instantiation instead of setting it immediately after
  * Fix an issue in Wand discovery when using Input System, no longer assigns multiple Wands to the wrong user
  * Fix conditions where without a valid Glasses pose, the Gameboard type property would return an invalid integer value of 0 instead of `GameboardType_None`
  * Add Android ARMv7 and ARM64 libraries with minimum supported Unity version of 2019 LTS
  * Add Linux x86-64 library

## [1.3.0] - Inquisitive Imps
* Control Panel
  * Status for Glasses now has three sections for the Glasses, the application running, and Wands connected to the Glasses
  * In Settings, there is now a toggle to allow or disallow the Camera Frame Sender to send IR Camera Frames from the Glasses, which is disabled by default
  * Show Glasses in the same order they will be acquired by games (including multi-player games)
  * Glasses attributes UI includes a new Health screen which can now display issues that have been seen since plugging in the Glasses (including a fix for Beta Issue #490)
  * A Volume Boost option has been added to the Glasses Info Actions tab. Note: it can cause audio to slightly clip or buzz in some conditions
  * For older production and all Beta Backer Glasses, report an unsupported USB speed correctly
  * Logging has been improved to be less noisy and the "Enhanced Logging" switch has been removed
  * "Beta" software banners appear when running beta versions of Control Panel, and a beta version number will appear on the bottom of the Control Panel

* Glasses
  * Perform pose prediction to anticipate movement, which greatly reduces a geometry "warping" effect most noticeable while moving your head sideways
  * Improve low-angle tracking so the Glasses can now track the board when you are closer to the surface
  * Integrate IMU data for tracking between visual tracking frames, improving pose re-acquisition after temporary loss of sight of the board
  * Fix issue where tracking would occasionally be lost at very narrow/specific angles on the XE raised Gameboard
  * Set temperature limits to be correct for all projectors and tweak throttling temperature values to fix Glasses cut off for one or both eyes (Issue #747)
  * Fix an issue (#787) where the Glasses could stop displaying until unplugged and re-plugged
  * Be more resilient to IMU timestamp data errors and occasional errors communicating with projectors
  * Turn off projectors when not displaying or tracking for lower power usage
  * Fix race condition for USB transport for multiple simultaneous Glasses

* Wands
  * Wands now report (in Control Panel) when they have a battery state too low to continue running
  * Wands now have a grace period for re-connection of a few seconds, when they are turned off or their batteries are removed

* Drivers and Tilt Five Software Install
  * Increase performance for generating Glasses images; can significantly improve frame rate for multiple Glasses
  * Fix issue where powering on two wands simultaneously could cause both wands to get the same address. To resolve, update the wand firmware for each wand. If wand firmware update is failing with multiple wands connected, turn off all wands, then turn on and update one at a time.
  * Fix a crash in the service when multiple Wands were being used
  * Added verification of system files at startup to prevent escalated security exploits
  * If the Service crashes or is stopped, all clients including the Control Panel must be restarted as they can no longer be considered trusted; the Control Panel will indicate this with a relevant error message and the system tray icon will automatically restart
  * The Tilt Five Glasses Camera Viewer has been moved to the Drivers install as it is a useful support tool
  * When the service restarts, flush stalled data that previously caused extra warnings to appear in logs
  * Service no longer deadlocks if clients are running when it is stopped, and restarts more cleanly
  * Control Panel will no longer show Glasses as still being used by the application if it exits without releasing the Glasses
  * Fix asynchronous USB pipe usage that would occasionally cause a crash in the Service
  * The Service no longer uses the Windows Event Log, and instead writes to rotating log files that are automatically cleaned up
  * Fix a crash that could occur when unplugging Glasses with connected Wands 
  * Enable better Glasses pose prediction based on SDK version and type; applications built using SDK version 1.3.0 and later will have a more accurate adjusted Glasses pose and more stable preview images on the host as a distinct motion-filtered preview pose is available in 1.3.0

* Developer Tools (Developer SDK)
  * If you are using the Mixcast SDK in your project, you should upgrade it to the latest version; Mixcast SDK version 2.5.1 and later is compatible with 1.3.0 when using TiltFiveManager2
  * Add `gameboard_transform` command line tool to experiment with tracking Gameboards at arbitrary rotations (tested primarily at 90 degrees on a wall) and/or scaling to a smaller or larger physical Gameboard size
  * The "Tilt Five Camera Viewer" tool is now in the Driver install and is renamed to "Tilt Five Glasses Camera Viewer"

* NDK (Developer SDK)
  * Add IR Camera Frame API to retrieve streams of images from the IR camera on each pair of Glasses
  * Rename the glasses "Acquire" operation to "Reserve" after much feedback from developers
  * Added a function for the NDK C++ interface to customize the SDK type, previously only supported by the C interface
  * Clean up and document more APIs

* Unity Plug-in (Developer SDK)
  * Add support for multiple simultaneously-connected Glasses for multiple local players using TiltFiveManager2 for multi-Glasses support. The original TiltFiveManager is kept for backward compatibility, but it does not support multiple Glasses; new projects should prefer TiltFiveManager2 over TiltFiveManager
  * Add support for specifying up to two Wands, right and left, per Glasses (both in TiltFiveManager and TiltFiveManager2)
  * Add IR Camera Frame API in Unity
  * Add multiple Player configuration tabs in TiltFiveManager2 for configuring the user experience for multiple Glasses
  * Move global system configuration information to its own panel in TiltFiveManager2
  * Add Upgrade button in Unity for TiltFiveManager to transfer settings to a new TiltFiveManager2 instance
  * Add upgrade steps documentation to ease transition to TiltFiveManager2
  * Camera template children objects now have an option to be cloned automatically
  * Log lack of plug-in as info level instead of error, don't log on unload
  * The Tilt Five Camera in the prefab now uses a smoothed glasses pose by default for an improved onscreen preview. If this camera was previously being used for tracking where the glasses are pointed, please either change to use an associated eye camera such as via `TiltFive.Glasses.GetLeftEye(PlayerIndex.One)` or use the pose information instead. For an example, see the SceneCursor scene in the Unity SDK examples.
  * Unity Action Maps can be defined for each Player's left and right Wands when using an `InputControlScheme` (a feature missing from the Beta, Issue #792)
  * Add notes about not using the Tilt Five Camera as a way to assume the Glasses pose since this is not likely to be correct in 1.3.0 and later in the SceneCursor example, which previously made this assumption
  * Default the TiltFiveManager2 prefab to GlassesMirrorMode.None, which provides a smoothed pose; other mirror modes result in using the real glasses pose for the respective eye(s) which has motion prediction applied, resulting in a very "shaky" image in the on-screen preview

* Unreal Plug-in (Public Beta; Download from tiltfive.com)
  * Support for Unreal 4.25, 4.26 and 4.27 using the Unreal AR/XR APIs with a single pair of Glasses and up to two Wands
  * Added support for IR Camera Frame API
  * Ensure already connected wands are properly flagged in the wand states
  * Implement GetFOV to fix rare startup bug in engine plug-in
  * Add blueprint for isUIRequestingAttention

* Fixed Issues Since Public Beta 1.3.0-beta.7
  * Control Panel's current running app font is normal size (fixed Beta Issue #738)
  * Control Panel closes after selecting Exit from system tray icon (fixed Beta Issue #78)
  * Glasses appears in the system tray when launched after the initial install (fixed Beta Issue #725)
  * The Control Panel setting for showing the Glasses icon in the system tray was not being honored (fixed Beta Issue)
  * You can now uncheck the Control Panel's "Include hardware info" checkbox when saving a log package (fixed Beta Issue #697) and when checked the Control Panel explains what is contained in that information
  * When "Include hardware info" is checked, DxDiag.exe output in the diagnostic package is generated (fixed Beta Issue #272)
  * Use direct DMA in and out on the Glasses for the IR Camera frame images, improving performance
  * Unity SDK Examples no longer require IL2CPP backend module (fixed Beta Issue #791)
  * Fix an exception that was being thrown on Unity scene switches (fixed Beta Issue #814)
  * Display.GetGlassesAvailability now reports when any Glasses are attached, not just the first player's Glasses (which might be removed during a game)
  * Fix the `gameboard_transform` developer tool to correctly track larger or smaller gameboards

* Known Issues for 1.3.0
  * Tooltip UI in the Unity Editor and the toString() method uses obsolete words primary and secondary for right and left wand enum #793
  * The `gameboard_transform` utility in the Developer SDK on Windows needs to run in a shell with Administrator privileges #884


## [1.2.2] - Huggable Hellhound
* Drivers and Tilt Five Software Install
  * Fix issue where settings could be wrong or uninitialized if newer settings or partial settings were left behind from a previous install, potentially leaving control panel unresponsive when attempting to change IPD
  * Improve error reporting when unable to apply or read settings on Windows
  * Fix wand streams when multiple glasses are connected that each have one or more paired wands

* Unity Plug-in (Developer SDK)
  * Fix InitializeOnLoad build error
  * Fix lost button change events in certain conditions when using Input System for Wand events

## [1.2.1] - Huggable Hellhound
* Control Panel
  * Avoid placing the Control Panel window behind task bars, make sure it opens in usable screen area
  * Fix LED color names and references to T5 button to be consistent with post-beta wands in the Wand pairing flow

* Glasses
  * Improve XE Board tracking when raised
  * Fix lack of volume controls when Glasses are in sleep mode
  * Prevent leaving an IR illumination LED on in unusual error conditions

* Wands
  * Tracking of Wand position for one participant will no longer be affected by another participant's Wand

* Drivers and Tilt Five Software Install
  * After 1.2.1 is upgraded to a future version or if it is re-installed, your settings will be retained; you can still remove these settings by running the uninstaller manually and choosing the "Remove user settings" option
  * Fixed an issue when multiple glasses are plugged in where the service becomes unstoppable (requiring force quit) and wand input stops working

* Unity Plug-in (Developer SDK)
  * Set displayName of Wand controllers for Input System to "Tilt Five Wand"
  * Return correct TiltFiveManager object consistently in the Unity Editor; sometimes a different prefab component was being returned

## [1.2.0] - Huggable Hellhound
* Control Panel
  * Fix error reporting for firmware validity from the system tray
  * Logging file size reductions for users who turn on developer mode's extended logging

* Glasses
  * Reconnecting the Glasses in the middle of the game after disconnecting them will be less likely to fail to restore video to the Glasses
  * Consistent 60 FPS display framerate (developers should use a constant 60 FPS target to benefit)
  * Fan speed is more consistently maintained (note: does not apply to Beta glasses hardware)
  * Gameboard position tracking improvements

* Wand
  * Significantly improved latency for movement tracking
  * Tracking is more robust when communication to the Wand has packet losses

* Drivers and Tilt Five Software Install
  * Introducing support for MixCast webcam composition streaming; you must be using the Driver version 1.2 or later with content which has integrated MixCast support

* Native Development Kit Beta (Developer SDK)
  * Change where the graphics context is created to initialization instead of when Glasses are acquired
  * You will need to update your use of the NDK with this version; note that NDK is still in beta and breaking changes may occur
  * See the HTML(Doxygen) docs for the NDK for full details of changes

* Unity Plug-in (Developer SDK)
  * Support for InputSystem for Wands; Now you can use the InputSystem methods to access wand events and pose
  * Update of the "Tilt Five Wand Model" prefab so the scaling of the wand model is accurate at a 1:1 with world space, and sets its origin to be at the handhold pose center in the wand body, aligned directly with the tip
  * Fixed a bug where the same wand button events could occasionally fire on two consecutive frames

* Unreal Plug-in (Unreal Marketplace/Developer SDK)
  * Introducing the Unreal Plug-In for authoring content; the plug-in is available on the Unreal Marketplace and requires Driver version 1.2.0 or later
  * A sample project and documentation for the Unreal Plug-In are provided now in the Developer SDK

## [1.1.0] - Gnarly Gnoll
* Control Panel
  * Support for XE Gameboards
  * New gameboard configuration UI for choosing your gameboard layout and rotation
  * Rename "wands" list to "accessories" and show the current gameboard in this list as an accessory
  * Allow scrolling of the accessories list to allow setting options for more than a few accessories
  * Fix a crash if the TiltFive App Data folder is missing and lazily create this folder to store logs
  * Use a more reliable logging mechanism, useful when Enhanced Logging setting is turned on
  * Display wand serial numbers correctly

* Glasses
  * Correctly wake if Glasses are sleeping for certain interactions
  * Allow for booting and response to simple commands when plugged into a USB2 port
  * Update firmware to recognize XE gameboard tracking points and newer LE gameboard points (to avoid crossing a fold or cut line)
  * Run cooling fans at a constant rate, except in some pre-production glasses (such as Kickstarter Beta Backer models) which still vary the fan speed

* Wand
  * Update Wand tracking algorithms for better computation of its location
  * Set a minimum amount of travel for the wand's analog joystick to register off-center movement, to resolve some drift issues reported
  * Fix some situations where the SDK would report wands disappearing
  * Fix a bug that caused wand tracking to become unstable after extended use

* Drivers and Tilt Five Software Install
  * Fix uninstaller issue where a few files were not removed and update the uninstaller executable filename
  * The Tilt Five Service, Notifier and Unity plugin files are now signed Windows binaries

* Native Development Kit Beta (Developer SDK)
  * The initial beta release of the NDK for Windows is included in the Developer SDK!
  * The NDK is the same infrastructure used for the other SDKs and allows low level access to the Glasses and Wands

* Unity Plug-in (Developer SDK)
  * Support for the XE Gameboard with the Unity gameboard gizmo
  * Option in the editor to manually override the Control-Panel-selected gameboard type for the gizmo
  * Unload on application quit or when stopping play in the Unity Editor, elimnating the need to restart the Unity Editor every time an application is run
  * Provide the user-defined glasses name from Control Panel to Unity
  * Apply scaling to the camera near and far clipping planes to keep the user experience consistent
  * Fix a bug where the Unity process can be stuck open because of a D3D device still in use
  * Getting glasses pose now returns an error if the board is not in view
  * "System" and "Z" button names are deprecated, please use "T5" and "Three" in new code

## [1.0.1] - Frenetic Flumph
* Control Panel
  * Added Beta Backer credits to the About screen
  * Fixed issue where Notifier sometimes failed to start
  * Fixed issue causing Control Panel to have high CPU usage

* Glasses
  * Adjusted speaker output level and EQ

* Wand
  * Made tracking more robust to distractions in the environment

* Unity Plug-in (Developer SDK)
  * Fixed an issue where the wand fingertips and aim pose lagged behind the grip pose

## [1.0.0] - Frenetic Flumph
* Control Panel
  * No longer defaults to developer mode on installation
  * System tray icon shows when glasses are plugged in or the Tilt Five Control Panel is started
  * Fix focus issues interacting with the system tray
  * Logging improvements for better issue reporting, including a “Save log package” menu item to generate a ZIP file with pertinent logs
  * Redesigned wand details UI
  * Wand pairing LED examples updated for new Wand pairing experience
  * Show progress of updating wands
  * Show additional wand details such as serial number, hardware revision, and calibration state and make text such as this selectable and copiable to the clipboard
  * Can now detect the connection state of the service and offer a support link to help fix the problem on your PC
  * Fix a bug where the tray icon could remain visible after exiting

* Glasses
  * Position tracking improvements
  * Calibration improvements
  * Allow glasses to be identified by Windows with proper names
  * Fix a bug where glasses could not be found on some systems
  * Verify glasses are running the correct firmware version for a particular session
  * Thermal thresholds tweaked for newer versions of the hardware

* Wand
  * Radio protocol improvements
  * Search for wand speed improved
  * LED flashing colors updated for pairing status display
  * Tracking position using both movement and video feedback from glasses
  * New LED pattern variants supported for future multiplayer uses
  * LED brightness adjustments
  * Software update is more likely to complete in low-battery states
  * Wand position updates are now synchronized with V-Sync
  * Multiple wand LED state fixed
  * Accessibility options per wand for inverting the Y axis and swapping the 1 and 2 buttons
  * Allow for greater maximum acceleration during wand shaking for better tracking of gestures
  * Fix issues where wand reconnection to a power-cycled glasses would disable V-Sync

* Drivers and Tilt Five Software Install
  * Use separate installers for driver (required for all users) and developer SDK
  * Installer signed with Tilt Five’s public certificate
  * Better performance for certain USB data streaming cases and control updates
  * Logging improvements for better issue reporting including log rotation

* Unity Plug-in (Developer SDK)
  * Simplify post-processing setup
  * Fix bug where letterboxing black bars could display stale data
  * Fix bug where Unity plug-in calls could block the caller for up to 600ms when there was no Tilt Five service running
  * Fix a build error where pluginversion.txt was not found by Unity

## [0.15.0] - Excellent Elemental
* Added
  * Firmware: Added initial microphone support
  * Firmware: Added low-power "sleep" mode and thermal-backoff throttling
  * Firmware: Added projector temperature monitoring
  * Firmware: Added the ability to hard-reset the SoC via GPIO
  * Firmware: Enabled additional code quality tools (Inc global [[nodiscard]])
  * Host: Added internal support for multiple devices
  * Host: Added platform specific settings storage
  * Host: Major restructure of host side software
  * Misc: Added additional display modes to internal test tools
  * Misc: Added enhanced versioning utilities
  * SDK: Gameboard type added to pose information
* Changes
  * Control Panel: Added placeholder device while device reboots
  * Firmware: Adjusted default USB speaker volume
  * Firmware: Audio Code cleanup
  * Firmware: Error checking code cleanup
  * Firmware: Improved warper pixel sampling location
  * Firmware: Misc improvements to USB handling
  * Firmware: Reduce SPI traffic for radio
  * Firmware: Restructured USB interfaces
  * Host: Improved uninstaller
  * Host: Moved wand tracking out of SDK into service
  * Host: Optimized client side IMU data structures
  * Host: Switched from UMDF to WinUSB based driver
  * Host: Switched to abstract firmware providers (OS independent)
  * Host: Switched to UNICODE builds by default
  * Host: Updated Flutter to 2.5.3
  * Host: Windows installer checks to ensure Windows 10, version 1703+ is in use
  * Misc: Added multiple string handling utilities
  * Misc: Formatting improvements throughout codebase
  * Misc: Reimplement internal test tools using NDK (Liveview, Squares, Wandviz)
  * Misc: Updated internal build tools
  * Misc: Utility code cleanup
  * Unity Plugin: Code cleanup
  * Unity Plugin: Integrated "TrackingUpdated" flag into TrackableCore
* Fixes
  * Control Panel: Multiple small fixes
  * Factory Software: Multiple small fixes
  * Firmware: Added workarounds for I2S driver bugs
  * Firmware: Fixed a source of audio crackle (DAC clock settings)
  * Firmware: Multiple small fixes
  * Unity Plugin: Added a warning for bad head pose camera scale
  * Unity Plugin: Added pupillary distance query to Unity SDK
  * Unity Plugin: Automatic reject bad wand states
  * Unity Plugin: Fixed multiple small issues with 3d API integration
  * Unity Plugin: Multiple small fixes
  * Wand Firmware: Multiple small fixes

## [0.14.1] - Debonair Draugr
* Improved dark color rendering
* Rotated the default gameboard orientation to match the physical gameboard.
  * Scene should no longer be rotated 90° when the T5 logo faces the user.
* Updated SDK-Examples to 1.10
* Added 3D models for wand and glasses
* Fix for jittery behavior when moving the virtual gameboard around in the scene.
* Slightly improved sharpness / readability by reducing default FOV from 55 to 48.
* Audio corruption fix
  * Clicks are still expected, with another fix coming in the next release.
* Various display bug fixes


## [0.14.0] - Debonair Draugr
* New Control Panel
  * Switched to Flutter-based UI
  * Added Wand Pairing & diagnostics GUI
  * Shows Glasses connectivity status
  * Built in release notes
* Added new SDK Installer
* Added Uninstaller
* Implemented additional tracked points on the wand, such as the wand tip
* Fix for USB instability on some host controllers
* Slightly improved wand tracking
* Improved Glasses image stabilization
* Known Issue: Spurious "Unsupported USB port" after fixing a backwards USB-C adapter
* Known Issue: Occasional control panel crashes
* Known issue: Occasional color field separation

## [0.13.0] - Collaborative Cyclops
* Added support for scriptable render pipelines
* Reorganized SDK scripts; now using assembly definitions

## [0.12.1] - Bashful Basilisk
* Added support for factory-built glasses

## [0.12.0] - Bashful Basilisk
* Added initial visual-only Wand Tracking support
  * **Limitation**: 30Hz wand pose updates
  * **Known issue**: Coaxial rotations (i.e. twisting the wand in place) are not yet tracked
  * Added a simple wand tracking demo that mirrors the wand pose under the game board's surface
* Added post processing support
* Added new scenes to sdk-examples project
  * These reference implementations demonstrate interaction models and UI experiments that developers may find thought-provoking or helpful while developing their own applications
* New Wand firmware (0.7.4)
  * Wand LED blinks green when connected to save power
* Updated wand_pairing tool
  * Pairing code sequence reduced to 4 button presses
  * Increased stability of the pairing/updating process
* Tweaked TiltFiveManager's custom inspector to separate scale and game board settings from the glasses settings
* Default IPD set to 59mm

### [0.11.2] - Alliterative Alpaca
* Updated wand pairing tool and pairing instructions

### [0.11.1] - Alliterative Alpaca
* Fixed typo in .bat file

## [0.11.0] - Alliterative Alpaca
* Added new Windows Driver installer
* Added new Tilt Five Control Panel
  * **Known Issue**: 'Help>Check for Updates' menu option on the control panel goes to a web page that doesn't exist
  * **Known Issue**: 'Tools>Logdog' and 'Tools>Liveview' menu options on the control panel show a 'something went wrong' message (Liveview and logdog are not included in this release)
  * **Known Issue**: Launching the control panel on Windows computers configured for Spanish or French will result in reduced menus, missing error messages and possibly crashes
* New Wand firmware (0.6)
* Enables the Wand to remember the most recently-paired Glasses
* Analog wand joystick/trigger values now span the expected ranges
  * **Known Issue**: Wand states may occasionally be dropped when the stick is fully tilted
    
## [0.10.0]
* Analog wand joystick/trigger values are more consistent
* Renamed GetStickAxis() to GetStickTilt() in TiltFive.Input
* Added TryGetButton(), TryGetButtonDown(), TryGetButtonUp(), TryGetStickTilt(), TryGetTrigger() to TiltFive.Input
* Known issue: Wand joystick and trigger values may not reach their minimum/maximum extents (e.g. stick values may span [-0.75,0.75] instead of [-1.0, 1.0])

## [0.9.0]
* Fixed missing audio on Windows
* Workaround on Windows for USB instability issue when connecting over SuperSpeedPlus

## [0.8.0]
* Added initial Windows 10 support

## [0.7.0]
* Added initial wand input support
  * **Known issue**: There may be some drift/bias on the joystick for this release. This can be mitigated somewhat just by tilting the stick all the way around to calibrate it

## [0.5.0]
* Enabled experimental audio out over the glasses speakers

## [0.4.0]
* Fixed bug causing reduced horizontal resolution
* Added stereoscopic preview mode
* Added letterboxing/pillarboxing when previewing the glasses cameras

## [0.3.0]
* Replaced udev rules setup script with .deb executable

## [0.2.0]
* Fixed an issue that sometimes caused tracking to fail on initial attempts to boot the glasses
* Increased the FOV of the projected image

## [0.1.0]
* Initial Release
